.. image:: images/AiiDA_transparent_logo.png
    :width: 250px
    :align: center
    :target: http://www.aiida.net/

The aiida-amber plugin for `AiiDA`_
=====================================================

``aiida-amber`` is available at http://github.com/CCPBioSim/aiida-amber

.. image:: images/amber-BioSimDB-logo.png
    :width: 250px
    :align: center
    :target: https://github.com/CCPBioSim/aiida-amber


.. toctree::
   :maxdepth: 2

   user_guide/index
   developer_guide/index
   API documentation <apidoc/aiida_amber>
   AiiDA Documentation <https://aiida.readthedocs.io>

If you use this plugin for your research, please cite the following work:

.. highlights:: TBD, watch this space.

If you use AiiDA for your research, please cite the following work:

.. highlights:: Giovanni Pizzi, Andrea Cepellotti, Riccardo Sabatini, Nicola Marzari,
  and Boris Kozinsky, *AiiDA: automated interactive infrastructure and database
  for computational science*, Comp. Mat. Sci 111, 218-230 (2016);
  https://doi.org/10.1016/j.commatsci.2015.09.013; http://www.aiida.net.

``aiida-amber`` is released under the MIT license.

Please contact Jas Kalayan jas.kalayan@stfc.ac.uk  or James Gebbie-Rayet james.gebbie@stfc.ac.uk for information concerning ``aiida-amber`` and the `AiiDA mailing list <http://www.aiida.net/mailing-list/>`_ for questions concerning ``aiida``.

Funding
=======

Contributors to aiida-gromacs were supported by

.. image::  images/psdi-logo.png
   :height: 100px
   :target: https://www.psdi.ac.uk/

.. image:: images/ccpbiosim-logo-white-background.png
   :height: 100px
   :target: https://www.ccpbiosim.ac.uk/

.. image:: images/cosec-logo.png
   :height: 100px
   :target: https://www.scd.stfc.ac.uk/Pages/CoSeC.aspx

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _AiiDA: http://www.aiida.net
